---
title: <span class="badge object-type-scalar"></span> NormalCubicMeter
---
# <span class="badge object-type-scalar"></span> NormalCubicMeter

Volume: Normal cubic meter

## Definition

```python
# Volume: Normal cubic meter
NormalCubicMeter: typing.Literal["Nm3"] = "Nm3"
```
